<?php 
/**
 *
 * @package   GS_Pinterest_Portfolio
 * @author    GS Plugins <hello@gsplugins.com>
 * @license   GPL-2.0+
 * @link      https://www.gsplugins.com
 * @copyright 2016 GS Plugins
 *
 * @wordpress-plugin
 * Plugin Name:			GS Pins for Pinterest Lite
 * Plugin URI:			https://www.gsplugins.com/wordpress-plugins
 * Description:       	Best Responsive Pinterest plugin for WordPress to showcase Pinterest Pins. Display anywhere at your site using shortcode like [gs_pinterest] & widgets. Check more shortcode examples and documentation at <a href="https://pinterest.gsplugins.com">GS Pinterest Porfolio PRO Demos</a> | <a href="https://docs.gsplugins.com/gs-pinterest-portfolio">Docs</a>
 * Version:           	1.6.1
 * Author:       		GS Plugins
 * Author URI:       	https://www.gsplugins.com
 * Text Domain:       	gs-pinterest
 * License:           	GPL-2.0+
 * License URI:       	http://www.gnu.org/licenses/gpl-2.0.txt
*/

// if direct access than exit the file.
defined('ABSPATH') || exit;

/**
 * Defining constants
 */
define( 'GSPIN_VERSION', '1.6.1' );
define( 'GSPIN_MENU_POSITION', 31 );
define( 'GSPIN_PLUGIN_DIR', plugin_dir_path( __FILE__ ) );
define( 'GSPIN_PLUGIN_URI', plugins_url( '', __FILE__ ) );
define( 'GSPIN_PLUGIN_BASENAME', plugin_basename( __FILE__ ) );

/**
 * Initiate Autoloader for Class Load
 * 
 * @since 2.0.8
 */
if ( ! class_exists( 'GSPIN\Autoloader' ) ) {
    require GSPIN_PLUGIN_DIR . 'includes/autoloader.php';
    GSPIN\Autoloader::init();

	require_once GSPIN_PLUGIN_DIR . 'asset-generator/gs-load-asset-generator.php';
}

/**
 * Activation redirects
 *
 * @since v1.0.0
 */
register_activation_hook(__FILE__, function() {
	gspin()->db->migration();
	add_option('gspin_activation_redirect', true);
});


/**
 * Initialize the plugin tracker
 *
 * @return void
 */
function appsero_init_tracker_gs_pinterest_portfolio() {

    if ( ! class_exists( 'GSPinAppSero\Insights' ) ) {
      require_once __DIR__ . '/appsero/Client.php';
    }

    $client = new GSPinAppSero\Client( '2bf3f746-49ec-410b-91e2-b0362b5f669a', 'GS Pinterest Portfolio', __FILE__ );

    // Active insights
    $client->insights()->init();

}

appsero_init_tracker_gs_pinterest_portfolio();

/**
 * Remove Reviews Metadata on plugin Deactivation.
 */
register_deactivation_hook(__FILE__, function() {
	delete_option('gspin_active_time');
	delete_option('gspin_maybe_later');
	delete_option('gsadmin_maybe_later');
});

if ( ! function_exists( 'gspin' ) ) {
	/**
	 * This function is responsible for running the main plugin.
	 * 
	 * @since  2.0.8
	 * @return object GSPIN The plugin instance.
	 */
	function gspin() {
		return GSPIN\GSPIN::getInstance();
	}
	gspin();
}

if ( ! function_exists( 'is_db_table_there' ) ) {
	function is_db_table_there() {
		global $wpdb;
		$query  = "SHOW TABLES LIKE '{$wpdb->prefix}gspin_shortcodes';";
		$result = $wpdb->get_results( $query );

		if ( empty( $result ) ) {
			return false;
		}

		return true;
	}
}

if( !function_exists( 'remove_pinterest_admin_notices' ) ) {
    function remove_pinterest_admin_notices( ) {
        if ( isset( $_GET['page'] ) && in_array( $_GET['page'], [ 'gsp-pinterest-main', 'gs-pinterest-plugins-premium', 'gs-pinterest-plugins-lite', 'gs-pinterest-plugins-help' ] ) ) {
            remove_all_actions( 'network_admin_notices' );
            remove_all_actions( 'user_admin_notices' );
            remove_all_actions( 'admin_notices' );
            remove_all_actions( 'all_admin_notices' );
        }
    }
}

add_action( 'in_admin_header',  'remove_pinterest_admin_notices' );

require_once GSPIN_PLUGIN_DIR . '/gs-common-pages/gs-pinterest-common-pages.php';

if ( is_db_table_there() ) {

	if ( 'gsPinBuilder' ) {
		/**
		 * This function is responsible for running the shortcode builder.
		 * 
		 * @since  2.0.12
		 * @return object GSPIN\ShortcodeBuilder\Builder The plugin instance.
		 */
		function gsPinBuilder() {
			return GSPIN\ShortcodeBuilder\Builder::get_instance();
		}
		gsPinBuilder();
	}
} else {
	/**
     * Admin Notice
     *
     * @since 1.0.0
     */
	add_action( 'admin_notices', function() {
        if ( current_user_can( 'install_plugins' ) ) {
            echo '<div class="gstesti-admin-notice updated" style="display: flex; align-items: center; padding-left: 0; border-left-color: #EF4B53"><p style="width: 32px;">';
            echo '
            <img style="width: 100%; display: block;" src="https://img.icons8.com/emoji/48/000000/warning-emoji.png"/></p><p> ';
            print( __('<strong>GS Pinterest Portfolio</strong> some how failed to create shortcodes database table. Deactive the plugin and activate again. Hopefully It\'ll solve the issue or <a class="button button-primary" href="https://www.gsplugins.com/contact/" target="_blank" style="text-decoration: none;">Please contact support</a>') );
            echo "</p></div>";
        }
    } );
    
}

add_action( 'init', function() {
	if ( version_compare( GSPIN_VERSION, '1.4.4', '>' ) && defined( 'GSPIN_PRO_VERSION' ) && ! version_compare( GSPIN_PRO_VERSION, '2.0.9', '>' ) ) {
		require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
		$plugin = 'gs-pinterest-portfolio-pro/gs_pinterest_portfolio.php';

		if ( is_plugin_active( $plugin ) ) {
			deactivate_plugins( $plugin );

			add_action( 'admin_notices', function() {
				if ( current_user_can( 'install_plugins' ) ) {
					echo '<div class="gstesti-admin-notice updated" style="display: flex; align-items: center; padding-left: 0; border-left-color: #EF4B53">';
					echo '<h4 style="margin-left: 15px">' . __( 'Please update GS Pinterest Portfolio PRO and try to activate again.', 'gs-pinterest' ) . '</h4>';
					echo "</div>";
				}
			});
		}
	}
});
