<?php

namespace GSPIN;

// if direct access than exit the file.
defined( 'ABSPATH' ) || exit;

class Pinterest {

    /**
     * Returns the fetched user pins.
     * 
     * @param  array $fields The specific fields names that need to map.
     * 
     * @since  2.0.9
     * @return array         The plucked pins based on the fields name.
     */
    public function getBoardPinsByUser( $username, $board, $count, $fields = [] ) {
        $transientKey = "gspin_{$username}_{$board}_pins";
        $savedData    = get_transient( $transientKey );

        if ( false === $savedData ) {

            if ( empty($board) ) {
                $url = sprintf( 'https://api.pinterest.com/v3/pidgets/users/%s/pins/', $username );
            } else {
                $url = sprintf( 'https://api.pinterest.com/v3/pidgets/boards/%s/%s/pins/', $username, $board );
            }
            
            $response = wp_remote_get( $url );

            if ( is_array( $response ) && ! is_wp_error( $response ) ) {
                $body = json_decode( wp_remote_retrieve_body( $response ), true );

                if ( ! empty( $body['data'] ) && ! empty( $body['data']['pins'] ) ) {
                    $savedData = $body['data']['pins'];
                    // set_transient( $transientKey, $savedData, HOUR_IN_SECONDS );
                    set_transient( $transientKey, $savedData, 30 );
                } else {
                    $savedData = [];
                }
            }
        }

        if ( ! empty( $savedData ) ) {
            $savedData = gspin()->helpers->pluck( $savedData, $count, $fields );
        }

        return $savedData;
    }
}