<?php

namespace GSPIN;

// if direct access than exit the file.
defined( 'ABSPATH' ) || exit;

/**
 * Responsible for the plugin shortcodes.
 * 
 * @since 2.0.8
 */
class Shortcodes {

	/**
	 * Constructor of the class.
	 * 
	 * @since 2.0.8
	 */
	public function __construct() {
		add_shortcode( 'gs_pinterest', array( $this, 'pinterestShortcode' ) );
		add_shortcode( 'gs_pin_widget', array( $this, 'pinWidget' ) );
		add_shortcode( 'gs_follow_pin_widget', array( $this, 'followPinShortcodeWidget' ) );
	}

	/**
	 * Renders pinterest main shortcode.
	 * 
	 * @since 2.0.8
	 * 
	 * @param  array $atts Shortcode attributes.
	 * @return html        Output markup.
	 */
	public function pinterestShortcode( $atts ) {

	
		$is_preview = ! empty($atts['preview']);
		$atts['id'] = $atts['id'] ?? '';

		$settings = (array) $this->gspinterest_get_temp_settings( $atts['id'], $is_preview ) ?? [];

		$settings['id'] = $atts['id'];
		$settings['is_preview'] = $is_preview;

		// By default force mode
		$force_asset_load = true;

		if ( ! $is_preview ) {
    
			// For Asset Generator
			$main_post_id = gsPinterestGenerator()->get_current_page_id();
	
			$asset_data = gsPinterestGenerator()->get_assets_data( $main_post_id );
	
			if ( empty($asset_data) ) {
				// Saved assets not found
				// Force load the assets for first time load
				// Generate the assets for later use
				gsPinterestGenerator()->generate( $main_post_id, $settings );
			} else {
				// Saved assets found
				// Stop force loading the assets
				// Leave the job for Asset Loader
				$force_asset_load = false;
			}
		}
 

		$atts            = gsPinBuilder()->manager->getShortcodeDefaultSettings( $atts );
		$gutter          = gspin()->helpers->getOption( 'gs_pins_gutter', 10 );
		$gs_pin_title    = gspin()->helpers->getOption( 'gs_pin_title', 'on' );
		$gs_pin_link_tar = gspin()->helpers->getOption( 'gs_pin_link_tar', '_blank' );

		// Build settings for the preview.
		if ( gsPinBuilder()->preview->isPreview() ) {

			// if ( empty($atts['id']) ) {
			// 	return __( 'No shortcode ID found', 'gs-pinterest' );
			// }

			$shortcode = gsPinBuilder()->manager->getTempSettings( $atts['id'] );
			$username  = $shortcode['userid'];
			$board     = $shortcode['board_name'];
			$count     = $shortcode['count'];
			$settings  = $shortcode['shortcode_settings'];
			$theme     = $settings['theme'];
			$gs_pin_title = $shortcode['show_pin_title'];
			$gs_pin_link_tar = $settings['link_target'];
		} else {
			// Build settings if it's from shortcode builder.
			if ( gspin()->helpers->isFromShortcodeBuilder( $atts ) ) {
				$shortcode = gsPinBuilder()->manager->getShortcodeById( $atts[ 'id' ], false );

				$username = $shortcode ? $shortcode['userid'] : '';
				$board    = $shortcode ? $shortcode['board_name'] : '';
				$count    = $shortcode ? $shortcode['count'] : '';
				$settings = $shortcode ? $shortcode['shortcode_settings'] : '';
				$theme    = $settings ? $settings['theme'] : '';
				$gs_pin_title = $shortcode ? $shortcode[ 'show_pin_title' ] : '';
				$gs_pin_link_tar = $settings ? $settings['link_target'] : '';
			} else {
				// Build settings for the regular shortcode.
				$username =	$atts['user'] ?? '';
				$board    = $atts['board'] ?? '';
				$count    = $atts['count'] ?? '';
				$theme    = $atts['theme'] ?? 'gs_pin_theme1';
				$gs_pin_link_tar = $atts[ 'link_target' ];

			}
		}
		
		// responsive
		$desktop         = ! empty( $settings['columns'] ) ? $settings['columns'] : ( ($atts['cols']) ?? 3 );
		$tablet          = ! empty( $settings['columns_tablet'] ) ? $settings['columns_tablet'] : ( ($atts['cols']) ?? 2 );
		$mobile_portrait = ! empty( $settings['columns_mobile_portrait'] ) ? $settings['columns_mobile_portrait'] : ( ($atts['cols']) ?? 2 );
		$columns_mobile  = ! empty( $settings['columns_mobile'] ) ? $settings['columns_mobile'] : ( ($atts['cols']) ?? 1 );
		$columnClasses   = gspin()->helpers->getColumnClasses( $desktop, $tablet, $mobile_portrait, $columns_mobile );
		$fields          = [ 'id', 'description', 'images' ];

		if ( empty( $username ) ) {
			return esc_attr__( 'Pinterest username is invalid or empty', '' );
		}

		if ( 'gs_pin_theme6' !== $theme ) {
			$pinterestBoards = new \GSPIN\Pinterest();
			$gs_rss_pins     = $pinterestBoards->getBoardPinsByUser( $username, $board, $count, [ 'id', 'description', 'images' ] );
		}

		$output = '';
		$output .= sprintf( '<div class="gs_pin_area %s" data-gutter="%s">', $theme, $gutter );
			
		$template = 'gs_pinterest_structure_one.php';

		if ( gspin()->helpers->isProActive() ) {
			if ( 'gs_pin_theme2' === $theme ) {
				$template = 'gs_pinterest_structure_two.php';
			}

			if ( 'gs_pin_theme3' === $theme ) {
				$template = 'gs_pinterest_structure_three_hov.php';
			}

			if ( 'gs_pin_theme4' === $theme ) {
				$template = 'gs_pinterest_structure_four_pop.php';
			}

			if ( 'gs_pin_theme5' === $theme ) {
				$template = 'gs_pinterest_structure_five_grey.php';
			}

			if ( 'gs_pin_theme6' === $theme ) {
				$template = 'gs_pinterest_user_profile.php';
			}
		}

		include TemplateLoader::locate_template( $template );

		$output .= gspin()->helpers->generateStyles( $gutter );
		$output .= gspin()->helpers->generateScripts();

		$output .= '</div>';

		// Fire force asset load when needed
		if ( $force_asset_load ) gsPinterestGenerator()->force_enqueue_assets( $settings );
		
		return $output;
	}

	public function gspinterest_get_temp_settings( $id, $is_preview = false ) {

		if ( $is_preview ) return get_transient( $id );
	
		$shortcode = gsPinBuilder()->manager->getShortcode( $id, false );
	
		if ( $shortcode ) return $shortcode['shortcode_settings'];
	
		return [];
		
	}

	/**
	 * Pin widget shortcode.
	 * 
	 * @since 2.0.8
	 * 
	 * @param  array $atts Shortcode attributes.
	 * @return html        Output markup.
	 */
	public function pinWidget( $atts ) {
		$atts = shortcode_atts(
			array(
				'pin_link'  => '',
				'pin_width' => ''
			),
			$atts 
		);

		$output = '';
		$output .= '<div class="pin-widget-area">';
			$output .= '<a data-pin-do="embedPin" data-pin-width="'. $atts['pin_width'] .'" href="'. $atts['pin_link'] .'"></a>';
		$output .= '</div>';
		return $output;
	}

	/**
	 * Follow Pin widget shortcode.
	 * 
	 * @since 2.0.8
	 * 
	 * @param  array $atts Shortcode attributes.
	 * @return html        Output markup.
	 */
	public function followPinShortcodeWidget( $atts ) {
		$atts = shortcode_atts(
			array(
				'pin_user'     => '',
				'follow_lebel' => ''
			),
			$atts
		);

		$output = '';
		$output .= '<div class="pin-follow-widget-area">';
			$output .= sprintf(
				'<a data-pin-do="buttonFollow" href="https://www.pinterest.com/%s/">%s</a>',
				$atts['pin_user'], $atts['follow_lebel']
			);
		$output .= '</div>';
		return $output;
	}
}