<?php

namespace GSPIN;

defined( 'ABSPATH' ) || exit;

final class TemplateLoader {

    private static $template_path = '';

    private static $template_pro_path = '';

    private static $theme_path = '';

    private static $_instance = null;
    
    public static function get_instance() {

        if ( is_null( self::$_instance ) ) {
            self::$_instance = new TemplateLoader();
        }

        return self::$_instance;
        
    }

    public function __construct() {

        self::$template_path = GSPIN_PLUGIN_DIR . 'templates/';

        if ( defined('GSPIN_PRO_PLUGIN_DIR') ) {
            self::$template_pro_path = GSPIN_PRO_PLUGIN_DIR . 'templates/';
        }

        add_action( 'init', [$this, 'set_theme_template_path'] );

    }

    public function set_theme_template_path() {

        $path = apply_filters( 'gs_pinterest_templates_folder', 'gs-pinterest' );

        if ( $path ) {
            $path = '/' . trailingslashit( ltrim( $path, '/\\' ) );
            self::$theme_path = get_stylesheet_directory() . $path;
        }

    }

    public static function locate_template( $template_file ) {

        // Default path
        $path = self::$template_path;
        
        if ( file_exists( self::$theme_path . $template_file ) ) {
            // Override default template if exist from theme
            $path = self::$theme_path;
        } else if ( defined('GSPIN_PRO_PLUGIN_DIR') ) {
            // Override default template if exist from Pro
            if ( file_exists( self::$template_pro_path . $template_file ) ) $path = self::$template_pro_path;
        }
        
        // Check requested file exist
        if ( ! file_exists( $path . $template_file ) ) return new \WP_Error( 'gspin_template_not_found', __( 'Template file not found - GsPlugins', 'gs-pinterest' ) );

        // Return template path, it can be default or overridden by theme
        return $path . $template_file;

    }

}